# Pytest-Fantasy

![](https://secure.travis-ci.org/wangwenpei/fantasy.png?branch=master)
![](https://codecov.io/github/wangwenpei/fantasy/coverage.svg?branch=master)


Pytest plugin for Flask-Fantasy.